RePrIm (remotis project imperium (remote project control)) is comfortable software for manage files on your PC via telegram bot when you are away from your computer

just create such a py file, put it in the root folder of the project and run it
```python
#pip install reprim

import RePrIm
```
